@@ -11,7 +11,7 @@
 #' @param ref Desired git reference; could be a commit, tag, or branch name.
 #'   Defaults to master.
 #' @seealso Bitbucket API docs:
-#'   \url{https://confluence.atlassian.com/display/BITBUCKET/Use+the+Bitbucket+REST+APIs}
+#'   \url{https://confluence.atlassian.com/bitbucket/use-the-bitbucket-cloud-rest-apis-222724129.html}
 #' @family package installation
 #' @export
 #' @examples
@@ -20,18 +20,24 @@
 #' install_bitbucket("dannavarro/lsr-package")
 #' }
 install_bitbucket <- function(repo, username, ref = "master", subdir = NULL,
-                              auth_user = NULL, password = NULL, ...) {
+                              auth_user = NULL, password = NULL, force = FALSE,
+                              quiet = FALSE, ...) {
 
   remotes <- lapply(repo, bitbucket_remote, username = username, ref = ref,
     subdir = subdir, auth_user = auth_user, password = password)
 
-  install_remotes(remotes, ...)
+  if (!isTRUE(force)) {
+    remotes <- Filter(function(x) different_sha(x, quiet = quiet), remotes)
+  }
+
+  install_remotes(remotes, quiet = quiet, ...)
 }
 
 bitbucket_remote <- function(repo, username = NULL, ref = NULL, subdir = NULL,
                               auth_user = NULL, password = NULL, sha = NULL) {
 
   meta <- parse_git_repo(repo)
+  meta$ref <- meta$ref %||% ref %||% "master"
 
   if (is.null(meta$username)) {
     meta$username <- username %||% stop("Unknown username.")
@@ -96,3 +102,12 @@ remote_metadata.bitbucket_remote <- function(x, bundle = NULL, source = NULL) {
   )
 }
 
+#' @export
+remote_package_name.bitbucket_remote <- function(remote, ...) {
+  remote_package_name.github_remote(remote, url = "https://bitbucket.org", ...)
+}
+
+#' @export
+remote_sha.bitbucket_remote <-function(remote, ...) {
+  remote_sha.github_remote(remote, url = "https://bitbucket.org", ...)
+}
