@@ -1,7 +1,9 @@
 using_gcc49 <- function() {
-  isTRUE(sub("^gcc[^[:digit:]]+", "", Sys.getenv("COMPILED_BY")) >= "4.9.3")
+  isTRUE(sub("^gcc[^[:digit:]]+", "", Sys.getenv("R_COMPILED_BY")) >= "4.9.3")
 }
 
+gcc_arch <- function() if (Sys.getenv("R_ARCH") == "/i386") "32" else "64"
+
 # Need to check for existence so load_all doesn't override known rtools location
 if (!exists("set_rtools_path")) {
   set_rtools_path <- NULL
@@ -17,7 +19,8 @@ if (!exists("set_rtools_path")) {
       stopifnot(is.rtools(rtools))
       path <- file.path(rtools$path, version_info[[rtools$version]]$path)
 
-      if (using_gcc49()) {
+      # If using gcc49 and _without_ a valid BINPREF already set
+      if (using_gcc49() && is.null(rtools$valid_binpref)) {
         Sys.setenv(BINPREF = file.path(rtools$path, "mingw_$(WIN)", "bin", "/"))
       }
       rtools_paths <<- path
@@ -131,7 +134,9 @@ setup_rtools <- function(cache = TRUE, debug = FALSE) {
   TRUE
 }
 
-scan_path_for_rtools <- function(debug = FALSE) {
+scan_path_for_rtools <- function(debug = FALSE,
+                                 gcc49 = using_gcc49(),
+                                 arch = gcc_arch()) {
   if (debug) cat("Scanning path...\n")
 
   # First look for ls and gcc
@@ -139,13 +144,49 @@ scan_path_for_rtools <- function(debug = FALSE) {
   if (ls_path == "") return(NULL)
   if (debug) cat("ls :", ls_path, "\n")
 
-  gcc_path <- Sys.which("gcc")
-  if (gcc_path == "") return(NULL)
-  if (debug) cat("gcc:", gcc_path, "\n")
-
   # We have a candidate installPath
   install_path <- dirname(dirname(ls_path))
+
+  if (gcc49) {
+    find_gcc49 <- function(path) {
+      if (!file.exists(path)) {
+        path <- paste0(path, ".exe")
+      }
+      file_info <- file.info(path)
+
+      # file_info$exe should be win32 or win64 respectively
+      if (!file.exists(path) || file_info$exe != paste0("win", arch)) {
+        return(character(1))
+      }
+      path
+    }
+
+
+    # First check if gcc set by BINPREF/CC is valid and use that is so
+    cc_path <- RCMD("config", "CC", fun = system_output, quiet = !debug)
+
+    # remove '-m64' from tail if it exists
+    cc_path <- sub("[[:space:]]+-m[[:digit:]]+$", "", cc_path)
+
+    gcc_path <- find_gcc49(cc_path)
+    if (nzchar(gcc_path)) {
+      return(rtools(install_path, NULL, valid_binpref = TRUE))
+    }
+
+    # if not check default location Rtools/mingw_{32,64}/bin/gcc.exe
+    gcc_path <- find_gcc49(file.path(install_path, paste0("mingw_", arch), "bin", "gcc.exe"))
+    if (!nzchar(gcc_path)) {
+      return(NULL)
+    }
+  } else {
+    gcc_path <- Sys.which("gcc")
+    if (gcc_path == "") return(NULL)
+  }
+  if (debug) cat("gcc:", gcc_path, "\n")
+
   install_path2 <- dirname(dirname(dirname(gcc_path)))
+
+  # If both install_paths are not equal
   if (tolower(install_path2) != tolower(install_path)) return(NULL)
 
   version <- installed_version(install_path, debug = debug)
@@ -167,7 +208,7 @@ scan_registry_for_rtools <- function(debug = FALSE) {
 
   rts <- vector("list", length(keys))
 
-  for(i in seq_along(keys)) {
+  for (i in seq_along(keys)) {
     version <- names(keys)[[i]]
     key <- keys[[version]]
     if (!is.list(key) || is.null(key$InstallPath)) next;
@@ -219,8 +260,8 @@ is_compatible <- function(rtools) {
   r_version >= info$version_min && r_version <= info$version_max
 }
 
-rtools <- function(path, version) {
-  structure(list(version = version, path = path), class = "rtools")
+rtools <- function(path, version, ...) {
+  structure(list(version = version, path = path, ...), class = "rtools")
 }
 is.rtools <- function(x) inherits(x, "rtools")
 
