@@ -1,4 +1,4 @@
 library("devtools")
 
 res <- revdep_check()
-revdep_check_save_summary(res)
+revdep_check_save_summary()
